import { z } from 'zod';
export type ContractData = z.infer<typeof data>;
export type ContractTemplate = z.infer<typeof template>;
export type Endorsement = z.infer<typeof endorsement>;
export type Signature = z.infer<typeof signature>;
declare const endorsement: z.ZodObject<{
    pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    signature: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
}, "strip", z.ZodTypeAny, {
    pubkey: string;
    signature: string;
}, {
    pubkey: string;
    signature: string;
}>;
declare const signature: z.ZodObject<{
    pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    psig: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
}, "strip", z.ZodTypeAny, {
    pubkey: string;
    nonce: string;
    psig: string;
}, {
    pubkey: string;
    nonce: string;
    psig: string;
}>;
declare const template: z.ZodObject<{
    description: z.ZodString;
    agent: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
    members: z.ZodOptional<z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">>;
}, "strip", z.ZodTypeAny, {
    description: string;
    agent?: string | undefined;
    members?: string[] | undefined;
}, {
    description: string;
    agent?: string | undefined;
    members?: string[] | undefined;
}>;
declare const data: z.ZodObject<{
    info: z.ZodObject<{
        description: z.ZodString;
        admin: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        agent: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    }, "strip", z.ZodTypeAny, {
        description: string;
        admin: string;
        agent: string;
    }, {
        description: string;
        admin: string;
        agent: string;
    }>;
    meta: z.ZodObject<{
        block_id: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        open_txid: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
        close_txid: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
    }, "strip", z.ZodTypeAny, {
        block_id: string;
        open_txid: string | null;
        close_txid: string | null;
    }, {
        block_id: string;
        open_txid: string | null;
        close_txid: string | null;
    }>;
    room: z.ZodObject<{
        secret: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        nonce: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
        pubkey: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
        hash: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
    }, "strip", z.ZodTypeAny, {
        pubkey: string | null;
        hash: string | null;
        secret: string;
        nonce: string | null;
    }, {
        pubkey: string | null;
        hash: string | null;
        secret: string;
        nonce: string | null;
    }>;
    status: z.ZodEnum<["draft", "published", "active", "disputed", "closed"]>;
    members: z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">;
    endorsements: z.ZodArray<z.ZodObject<{
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        signature: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        signature: string;
    }, {
        pubkey: string;
        signature: string;
    }>, "many">;
    signatures: z.ZodArray<z.ZodObject<{
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        psig: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        nonce: string;
        psig: string;
    }, {
        pubkey: string;
        nonce: string;
        psig: string;
    }>, "many">;
    contract_id: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    revision: z.ZodNumber;
    created_at: z.ZodDate;
    updated_at: z.ZodDate;
}, "strip", z.ZodTypeAny, {
    status: "draft" | "published" | "active" | "disputed" | "closed";
    info: {
        description: string;
        admin: string;
        agent: string;
    };
    meta: {
        block_id: string;
        open_txid: string | null;
        close_txid: string | null;
    };
    room: {
        pubkey: string | null;
        hash: string | null;
        secret: string;
        nonce: string | null;
    };
    members: string[];
    endorsements: {
        pubkey: string;
        signature: string;
    }[];
    signatures: {
        pubkey: string;
        nonce: string;
        psig: string;
    }[];
    contract_id: string;
    revision: number;
    created_at: Date;
    updated_at: Date;
}, {
    status: "draft" | "published" | "active" | "disputed" | "closed";
    info: {
        description: string;
        admin: string;
        agent: string;
    };
    meta: {
        block_id: string;
        open_txid: string | null;
        close_txid: string | null;
    };
    room: {
        pubkey: string | null;
        hash: string | null;
        secret: string;
        nonce: string | null;
    };
    members: string[];
    endorsements: {
        pubkey: string;
        signature: string;
    }[];
    signatures: {
        pubkey: string;
        nonce: string;
        psig: string;
    }[];
    contract_id: string;
    revision: number;
    created_at: Date;
    updated_at: Date;
}>;
export declare const ContractSchema: {
    data: z.ZodObject<{
        info: z.ZodObject<{
            description: z.ZodString;
            admin: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            agent: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        }, "strip", z.ZodTypeAny, {
            description: string;
            admin: string;
            agent: string;
        }, {
            description: string;
            admin: string;
            agent: string;
        }>;
        meta: z.ZodObject<{
            block_id: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            open_txid: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
            close_txid: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
        }, "strip", z.ZodTypeAny, {
            block_id: string;
            open_txid: string | null;
            close_txid: string | null;
        }, {
            block_id: string;
            open_txid: string | null;
            close_txid: string | null;
        }>;
        room: z.ZodObject<{
            secret: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            nonce: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
            pubkey: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
            hash: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
        }, "strip", z.ZodTypeAny, {
            pubkey: string | null;
            hash: string | null;
            secret: string;
            nonce: string | null;
        }, {
            pubkey: string | null;
            hash: string | null;
            secret: string;
            nonce: string | null;
        }>;
        status: z.ZodEnum<["draft", "published", "active", "disputed", "closed"]>;
        members: z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">;
        endorsements: z.ZodArray<z.ZodObject<{
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            signature: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            signature: string;
        }, {
            pubkey: string;
            signature: string;
        }>, "many">;
        signatures: z.ZodArray<z.ZodObject<{
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            psig: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            nonce: string;
            psig: string;
        }, {
            pubkey: string;
            nonce: string;
            psig: string;
        }>, "many">;
        contract_id: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        revision: z.ZodNumber;
        created_at: z.ZodDate;
        updated_at: z.ZodDate;
    }, "strip", z.ZodTypeAny, {
        status: "draft" | "published" | "active" | "disputed" | "closed";
        info: {
            description: string;
            admin: string;
            agent: string;
        };
        meta: {
            block_id: string;
            open_txid: string | null;
            close_txid: string | null;
        };
        room: {
            pubkey: string | null;
            hash: string | null;
            secret: string;
            nonce: string | null;
        };
        members: string[];
        endorsements: {
            pubkey: string;
            signature: string;
        }[];
        signatures: {
            pubkey: string;
            nonce: string;
            psig: string;
        }[];
        contract_id: string;
        revision: number;
        created_at: Date;
        updated_at: Date;
    }, {
        status: "draft" | "published" | "active" | "disputed" | "closed";
        info: {
            description: string;
            admin: string;
            agent: string;
        };
        meta: {
            block_id: string;
            open_txid: string | null;
            close_txid: string | null;
        };
        room: {
            pubkey: string | null;
            hash: string | null;
            secret: string;
            nonce: string | null;
        };
        members: string[];
        endorsements: {
            pubkey: string;
            signature: string;
        }[];
        signatures: {
            pubkey: string;
            nonce: string;
            psig: string;
        }[];
        contract_id: string;
        revision: number;
        created_at: Date;
        updated_at: Date;
    }>;
    members: z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">;
    ref: z.ZodObject<{
        contract_id: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        updated_at: z.ZodDate;
    }, "strip", z.ZodTypeAny, {
        contract_id: string;
        updated_at: Date;
    }, {
        contract_id: string;
        updated_at: Date;
    }>;
    endorsement: z.ZodObject<{
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        signature: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        signature: string;
    }, {
        pubkey: string;
        signature: string;
    }>;
    signature: z.ZodObject<{
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        psig: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        nonce: string;
        psig: string;
    }, {
        pubkey: string;
        nonce: string;
        psig: string;
    }>;
    template: z.ZodObject<{
        description: z.ZodString;
        agent: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
        members: z.ZodOptional<z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">>;
    }, "strip", z.ZodTypeAny, {
        description: string;
        agent?: string | undefined;
        members?: string[] | undefined;
    }, {
        description: string;
        agent?: string | undefined;
        members?: string[] | undefined;
    }>;
};
export {};
//# sourceMappingURL=contract.d.ts.map